@@ -32,6 +32,27 @@ def wrap_text(p: Canvas, x: int, y: int, text: str, font_size: int, size: int) -
     return h
 
 
+def wrap_text_center(p: Canvas, x: int, y: int, text: str, font_size: int, size: int) -> int:
+    import textwrap
+    # noinspection PyProtectedMember
+    line_width = p._lineWidth
+    # noinspection PyProtectedMember
+    fontname = p._fontname
+
+    h = 0
+
+    p.setFontSize(font_size)
+    wrapped = textwrap.wrap(text, int(size / font_size * WRAP_FACTOR))
+    height = line_width * font_size * len(wrapped)
+
+    for line in wrapped:
+        w = p.stringWidth(line, fontname, font_size)
+        p.drawString(x - w / 2, y - font_size - h + height/2, line)  # y should point to the upper pixel of the text
+        h += line_width * font_size
+
+    return h
+
+
 def get_wrapped_text_height(p: Canvas, text: str, font_size: int, size: int) -> int:
     # noinspection PyProtectedMember
     line_width = p._lineWidth
